@@ -35,9 +35,9 @@
 class CatalogTreeView: public QTreeView
 {
 public:
-    CatalogTreeView(QWidget * parent)
+    explicit CatalogTreeView(QWidget * parent)
         : QTreeView(parent) {}
-    ~CatalogTreeView() {}
+    ~CatalogTreeView() = default;
 
 protected:
     void keyReleaseEvent(QKeyEvent *e) override
@@ -72,7 +72,7 @@ CatalogView::CatalogView(QWidget* parent, Catalog* catalog)
 
     m_lineEdit->setClearButtonEnabled(true);
     m_lineEdit->setPlaceholderText(i18n("Quick search..."));
-    m_lineEdit->setToolTip(i18nc("@info:tooltip", "Activated by Ctrl+L.") + ' ' + i18nc("@info:tooltip", "Accepts regular expressions"));
+    m_lineEdit->setToolTip(i18nc("@info:tooltip", "Activated by Ctrl+L. Accepts regular expressions"));
     connect(m_lineEdit, &QLineEdit::textChanged, this, &CatalogView::setFilterRegExp, Qt::QueuedConnection);
     // QShortcut* ctrlEsc=new QShortcut(QKeySequence(Qt::META+Qt::Key_Escape),this,SLOT(reset()),0,Qt::WidgetWithChildrenShortcut);
     QShortcut* esc = new QShortcut(QKeySequence(Qt::Key_Escape), this, nullptr, nullptr, Qt::WidgetWithChildrenShortcut);
@@ -314,3 +314,4 @@ void CatalogView::setEntriesFilteredOut(bool filteredOut)
     refreshCurrentIndex();
 }
 
+#include "moc_cataloglistview.cpp"
