@@ -21,6 +21,7 @@
 #include <QTimer>
 #include <QThreadPool>
 
+#include <kcoreaddons_version.h>
 #include <KLocalizedString>
 #include <KDirLister>
 
@@ -32,31 +33,18 @@ static int nodeCounter = 0;
 
 ProjectModel::ProjectModel(QObject *parent)
     : QAbstractItemModel(parent)
-    , m_poModel(this)
-    , m_potModel(this)
-    , m_rootNode(nullptr, -1, -1, -1)
-    , m_dirIcon(QIcon::fromTheme(QStringLiteral("inode-directory")))
-    , m_poIcon(QIcon::fromTheme(QStringLiteral("flag-blue")))
-    , m_poInvalidIcon(QIcon::fromTheme(QStringLiteral("flag-red")))
-    , m_poComplIcon(QIcon::fromTheme(QStringLiteral("flag-green")))
-    , m_poEmptyIcon(QIcon::fromTheme(QStringLiteral("flag-yellow")))
-    , m_potIcon(QIcon::fromTheme(QStringLiteral("flag-black")))
-    , m_activeJob(nullptr)
-    , m_activeNode(nullptr)
-    , m_doneTimer(new QTimer(this))
-    , m_delayedReloadTimer(new QTimer(this))
-    , m_threadPool(new QThreadPool(this))
-    , m_completeScan(true)
 {
     m_threadPool->setMaxThreadCount(1);
     m_threadPool->setExpiryTimeout(-1);
 
-    m_poModel.dirLister()->setAutoErrorHandlingEnabled(false, nullptr);
     m_poModel.dirLister()->setNameFilter(QStringLiteral("*.po *.pot *.xlf *.xliff *.ts"));
-
-    m_potModel.dirLister()->setAutoErrorHandlingEnabled(false, nullptr);
     m_potModel.dirLister()->setNameFilter(QStringLiteral("*.pot"));
 
+#if KCOREADDONS_VERSION < QT_VERSION_CHECK(6, 0, 0) // keep error handling disabled until it is removed
+    m_poModel.dirLister()->setAutoErrorHandlingEnabled(false, nullptr);
+    m_potModel.dirLister()->setAutoErrorHandlingEnabled(false, nullptr);
+#endif
+
     connect(&m_poModel, &KDirModel::dataChanged, this, &ProjectModel::po_dataChanged);
 
     connect(&m_poModel, &KDirModel::rowsInserted, this, &ProjectModel::po_rowsInserted);
@@ -650,9 +638,9 @@ QVariant ProjectModel::data(const QModelIndex& index, const int role) const
     const int translated = node->translatedAsPerRole();
     const int fuzzy = node->fuzzyAsPerRole();
     const int untranslated = node->metaData.untranslated;
-    QString comment(QStringLiteral(""));
+    QString comment(QLatin1String(""));
     if (Project::instance()->commentsFiles().count() > 0 && Project::instance()->commentsTexts().count() > 0) {
-        int existingItem = Project::instance()->commentsFiles().indexOf(Project::instance()->relativePath(item.localPath()));
+        const int existingItem = Project::instance()->commentsFiles().indexOf(Project::instance()->relativePath(item.localPath()));
         if (existingItem != -1 && Project::instance()->commentsTexts().count() > existingItem) {
             comment = Project::instance()->commentsTexts().at(existingItem);
         }
@@ -971,10 +959,10 @@ QUrl ProjectModel::poToPot(const QUrl& poPath) const
 
     //change ".po" into ".pot"
     if (pathToAdd.endsWith(QLatin1String(".po"))) //TODO: what about folders ??
-        pathToAdd += 't';
+        pathToAdd += QLatin1Char('t');
 
     QUrl potPath = m_potUrl;
-    potPath.setPath(potPath.path() + '/' + pathToAdd);
+    potPath.setPath(potPath.path() + QLatin1Char('/') + pathToAdd);
 
     //qCDebug(LOKALIZE_LOG) << "ProjectModel::poToPot("<< poPath.pathOrUrl() << +") = " << potPath.pathOrUrl();
     return potPath;
@@ -994,7 +982,7 @@ QUrl ProjectModel::potToPo(const QUrl& potPath) const
         pathToAdd = pathToAdd.left(pathToAdd.length() - 1);
 
     QUrl poPath = m_poUrl;
-    poPath.setPath(poPath.path() + '/' + pathToAdd);
+    poPath.setPath(poPath.path() + QLatin1Char('/') + pathToAdd);
 
     //qCDebug(LOKALIZE_LOG) << "ProjectModel::potToPo("<< potPath.pathOrUrl() << +") = " << poPath.pathOrUrl();
     return poPath;
@@ -1226,9 +1214,6 @@ ProjectModel::ProjectNode::ProjectNode(ProjectNode* _parent, int _rowNum, int _p
     , rowNumber(_rowNum)
     , poRowNumber(_poIndex)
     , potRowNumber(_potIndex)
-    , poCount(0)
-    , metaDataStatus(Status::NoStats)
-    , metaData()
 {
     ++nodeCounter;
 }
@@ -1275,3 +1260,5 @@ void ProjectModel::ProjectNode::resetMetaData()
     metaDataStatus = Status::NoStats;
     metaData = FileMetaData();
 }
+
+#include "moc_projectmodel.cpp"
