@@ -42,12 +42,6 @@ QThreadPool* TM::threadPool()
     return inst;
 }
 
-#ifdef Q_OS_WIN
-#define U QLatin1String
-#else
-#define U QStringLiteral
-#endif
-
 #define TM_DELIMITER '\v'
 #define TM_SEPARATOR '\b'
 #define TM_NOTAPPROVED 0x04
@@ -89,7 +83,7 @@ static void doSplit(QString& cleanEn,
         for (; i < words.size(); ++i) {
             if (words.at(i).size() < 4)
                 words.removeAt(i--);
-            else if (words.at(i).startsWith('t') && words.at(i).size() == 4) {
+            else if (words.at(i).startsWith(QLatin1Char('t')) && words.at(i).size() == 4) {
                 if (words.at(i) == QLatin1String("then")
                     || words.at(i) == QLatin1String("than")
                     || words.at(i) == QLatin1String("that")
@@ -109,11 +103,10 @@ static qlonglong getFileId(const QString& path,
     QString escapedPath = path;
     escapedPath.replace(QLatin1Char('\''), QLatin1String("''"));
 
-    QString pathExpr = QStringLiteral("path='") + escapedPath + '\'';
+    QString pathExpr = QStringLiteral("path='") + escapedPath + QLatin1Char('\'');
     if (path.isEmpty())
         pathExpr = QStringLiteral("path ISNULL");
-    if (Q_UNLIKELY(!query1.exec(U("SELECT id FROM files WHERE "
-                                  "path='") + escapedPath + '\'')))
+    if (Q_UNLIKELY(!query1.exec(QStringLiteral("SELECT id FROM files WHERE path='") + escapedPath + QLatin1Char('\''))))
         qCWarning(LOKALIZE_LOG) << "select db error: " << query1.lastError().text();
 
     if (Q_LIKELY(query1.next())) {
@@ -161,8 +154,7 @@ static void addToIndex(qlonglong sourceId, QString sourceString,
     int j = words.size();
     while (--j >= 0) {
         // insert word (if we do not have it)
-        if (Q_UNLIKELY(!query1.exec(U("SELECT word, ids_short, ids_long FROM words WHERE "
-                                      "word='") + words.at(j) + '\'')))
+        if (Q_UNLIKELY(!query1.exec(QStringLiteral("SELECT word, ids_short, ids_long FROM words WHERE word='") + words.at(j) + QLatin1Char('\''))))
             qCWarning(LOKALIZE_LOG) << "select error 3: " << query1.lastError().text();
 
         //we _have_ it
@@ -187,7 +179,7 @@ static void addToIndex(qlonglong sourceId, QString sourceString,
                 || arr == sourceIdStr)
                 return;//this string is already indexed
 
-            query1.prepare(QStringLiteral("UPDATE words SET ") + field + QStringLiteral("=? WHERE word='") + words.at(j) + '\'');
+            query1.prepare(QStringLiteral("UPDATE words SET ") + field + QStringLiteral("=? WHERE word='") + words.at(j) + QLatin1Char('\''));
 
             if (!arr.isEmpty())
                 arr += ' ';
@@ -234,11 +226,11 @@ static void removeFromIndex(qlonglong mainId, qlonglong sourceId, QString source
 
 //BEGIN check
     //TM_NOTAPPROVED=4
-    if (Q_UNLIKELY(!query1.exec(U("SELECT count(*) FROM main, target_strings WHERE "
-                                  "main.source=") + QString::number(sourceId) + U(" AND "
+    if (Q_UNLIKELY(!query1.exec(QStringLiteral("SELECT count(*) FROM main, target_strings WHERE "
+                                  "main.source=") + QString::number(sourceId) + QStringLiteral(" AND "
                                           "main.target=target_strings.id AND "
                                           "target_strings.target NOTNULL AND "
-                                          "main.id!=") + QString::number(mainId) + U(" AND "
+                                          "main.id!=") + QString::number(mainId) + QStringLiteral(" AND "
                                                   "(main.bits&4)!=4")))) {
         qCWarning(LOKALIZE_LOG) << "select error 500: " << query1.lastError().text();
         return;
@@ -254,8 +246,7 @@ static void removeFromIndex(qlonglong mainId, qlonglong sourceId, QString source
     int j = words.size();
     while (--j >= 0) {
         // remove from record for the word (if we do not have it)
-        if (Q_UNLIKELY(!query1.exec(U("SELECT word, ids_short, ids_long FROM words WHERE "
-                                      "word='") + words.at(j) + '\''))) {
+        if (Q_UNLIKELY(!query1.exec(QStringLiteral("SELECT word, ids_short, ids_long FROM words WHERE word='") + words.at(j) + QLatin1Char('\'')))) {
             qCWarning(LOKALIZE_LOG) << "select error 3: " << query1.lastError().text();
             return;
         }
@@ -287,9 +278,7 @@ static void removeFromIndex(qlonglong mainId, qlonglong sourceId, QString source
             arr.clear();
 
 
-        query1.prepare(U("UPDATE words "
-                         "SET ") + field + U("=? "
-                                             "WHERE word='") + words.at(j) + '\'');
+        query1.prepare(QStringLiteral("UPDATE words SET ") + field + QStringLiteral("=? WHERE word='") + words.at(j) + QLatin1Char('\''));
 
         query1.bindValue(0, arr);
 
@@ -303,7 +292,7 @@ static bool doRemoveEntry(qlonglong mainId, QRegExp& rxClean1, const QString& ac
 {
     QSqlQuery query1(db);
 
-    if (Q_UNLIKELY(!query1.exec(U("SELECT source_strings.id, source_strings.source FROM source_strings, main WHERE "
+    if (Q_UNLIKELY(!query1.exec(QStringLiteral("SELECT source_strings.id, source_strings.source FROM source_strings, main WHERE "
                                   "source_strings.id=main.source AND main.id=") + QString::number(mainId))))
         return false;
 
@@ -315,7 +304,7 @@ static bool doRemoveEntry(qlonglong mainId, QRegExp& rxClean1, const QString& ac
 
     query1.clear();
 
-    if (Q_UNLIKELY(!query1.exec(U("SELECT target_strings.id FROM target_strings, main WHERE target_strings.id=main.target AND main.id=") + QString::number(mainId))))
+    if (Q_UNLIKELY(!query1.exec(QStringLiteral("SELECT target_strings.id FROM target_strings, main WHERE target_strings.id=main.target AND main.id=") + QString::number(mainId))))
         return false;
 
     if (!query1.next())
@@ -353,7 +342,7 @@ static bool doRemoveFile(const QString& filePath, QSqlDatabase& db)
     qlonglong fileId = getFileId(filePath, db);
     QSqlQuery query1(db);
 
-    if (Q_UNLIKELY(!query1.exec(U("SELECT id FROM files WHERE "
+    if (Q_UNLIKELY(!query1.exec(QStringLiteral("SELECT id FROM files WHERE "
                                   "id=") + QString::number(fileId))))
         return false;
 
@@ -373,7 +362,7 @@ static int doRemoveMissingFiles(QSqlDatabase& db, const QString& dbName, QObject
     int deletedFiles = 0;
     QSqlQuery query1(db);
 
-    if (Q_UNLIKELY(!query1.exec(U("SELECT files.path FROM files"))))
+    if (Q_UNLIKELY(!query1.exec(QStringLiteral("SELECT files.path FROM files"))))
         return false;
 
     if (!query1.next())
@@ -440,7 +429,7 @@ static bool doInsertEntry(CatalogString source,
     QByteArray targetTags = target.tagsAsByteArray();
 
 //BEGIN get sourceId
-    query1.prepare(QString(U("SELECT id FROM source_strings WHERE "
+    query1.prepare(QString(QStringLiteral("SELECT id FROM source_strings WHERE "
                              "source=? AND (source_accel%1) AND source_markup%2")).arg
                    (sourceAccelPos != -1 ? QStringLiteral("=?") : QStringLiteral("=-1 OR source_accel ISNULL"),
                     sourceTags.isEmpty() ? QStringLiteral(" ISNULL") : QStringLiteral("=?")));
@@ -490,9 +479,9 @@ static bool doInsertEntry(CatalogString source,
 //END get sourceId
 
 
-    if (Q_UNLIKELY(!query1.exec(QString(U("SELECT id, target, bits FROM main WHERE "
+    if (Q_UNLIKELY(!query1.exec(QString(QStringLiteral("SELECT id, target, bits FROM main WHERE "
                                           "source=%1 AND file=%2 AND ctxt%3")).arg(sourceId).arg(fileId).arg
-                                (escapedCtxt.isEmpty() ? QStringLiteral(" ISNULL") : QString("='" + escapedCtxt + '\''))))) {
+                                (escapedCtxt.isEmpty() ? QStringLiteral(" ISNULL") : QString(QStringLiteral("='") + escapedCtxt + QLatin1Char('\'')))))) {
         qCWarning(LOKALIZE_LOG) << "doInsertEntry: select db main error: " << query1.lastError().text();
         return false;
     }
@@ -520,7 +509,7 @@ static bool doInsertEntry(CatalogString source,
         bool dbApproved = !(bits & TM_NOTAPPROVED);
         bool approvalChanged = dbApproved != approved;
         if (approvalChanged) {
-            query1.prepare(U("UPDATE main "
+            query1.prepare(QStringLiteral("UPDATE main "
                              "SET bits=?, change_date=CURRENT_DATE "
                              "WHERE id=") + QString::number(mainId));
 
@@ -533,7 +522,7 @@ static bool doInsertEntry(CatalogString source,
         query1.clear();
 
         //check if target in TM matches
-        if (Q_UNLIKELY(!query1.exec(U("SELECT target, target_markup, target_accel FROM target_strings WHERE "
+        if (Q_UNLIKELY(!query1.exec(QStringLiteral("SELECT target, target_markup, target_accel FROM target_strings WHERE "
                                       "id=") + QString::number(targetId)))) {
             qCWarning(LOKALIZE_LOG) << "doInsertEntry: select db target_strings error: " << query1.lastError().text();
             return false;
@@ -564,7 +553,7 @@ static bool doInsertEntry(CatalogString source,
             return false;
         }
         // no, translation has changed: just update old target if it isn't used elsewhere
-        if (Q_UNLIKELY(!query1.exec(U("SELECT count(*) FROM main WHERE "
+        if (Q_UNLIKELY(!query1.exec(QStringLiteral("SELECT count(*) FROM main WHERE "
                                       "target=") + QString::number(targetId))))
             qCWarning(LOKALIZE_LOG) << "doInsertEntry: select db target_strings error: " << query1.lastError().text();
 
@@ -572,7 +561,7 @@ static bool doInsertEntry(CatalogString source,
             //TODO tnis may create duplicates, while no strings should be lost
             query1.clear();
 
-            query1.prepare(U("UPDATE target_strings "
+            query1.prepare(QStringLiteral("UPDATE target_strings "
                              "SET target=?, target_accel=?, target_markup=? "
                              "WHERE id=") + QString::number(targetId));
 
@@ -596,7 +585,7 @@ static bool doInsertEntry(CatalogString source,
 //END target update
 
 //BEGIN get targetId
-    query1.prepare(QString(U("SELECT id FROM target_strings WHERE "
+    query1.prepare(QString(QStringLiteral("SELECT id FROM target_strings WHERE "
                              "target=? AND (target_accel%1) AND target_markup%2")).arg
                    (targetAccelPos != -1 ? QStringLiteral("=?") : QStringLiteral("=-1 OR target_accel ISNULL"),
                     targetTags.isEmpty() ? QStringLiteral(" ISNULL") : QStringLiteral("=?")));
@@ -642,7 +631,7 @@ static bool doInsertEntry(CatalogString source,
         //just update main with new targetId
         //(this is the case when target changed, but there were other users of the old one)
 
-        query1.prepare(U("UPDATE main "
+        query1.prepare(QStringLiteral("UPDATE main "
                          "SET target=?, bits=?, change_date=CURRENT_DATE "
                          "WHERE id=") + QString::number(mainId));
 
@@ -661,7 +650,7 @@ static bool doInsertEntry(CatalogString source,
         //this adds source to index if it's not already there
         addToIndex(sourceId, source.string, rxClean1, accel, db);
 
-    QString sql = U("INSERT INTO main (source, target, file, ctxt, bits, prior) "
+    QString sql = QStringLiteral("INSERT INTO main (source, target, file, ctxt, bits, prior) "
                     "VALUES (?, ?, ?, ?, ?, ?)");
     if (qpsql)
         sql += QLatin1String(" RETURNING id");
@@ -691,7 +680,7 @@ static bool initSqliteDb(QSqlDatabase& db)
     QSqlQuery queryMain(db);
     //NOTE do this only if no japanese, chinese etc?
     queryMain.exec(QStringLiteral("PRAGMA encoding = \"UTF-8\""));
-    queryMain.exec(U(
+    queryMain.exec(QStringLiteral(
                        "CREATE TABLE IF NOT EXISTS source_strings ("
                        "id INTEGER PRIMARY KEY ON CONFLICT REPLACE, "// AUTOINCREMENT,"
                        "source TEXT, "
@@ -699,7 +688,7 @@ static bool initSqliteDb(QSqlDatabase& db)
                        "source_accel INTEGER "
                        ")"));
 
-    queryMain.exec(U(
+    queryMain.exec(QStringLiteral(
                        "CREATE TABLE IF NOT EXISTS target_strings ("
                        "id INTEGER PRIMARY KEY ON CONFLICT REPLACE, "// AUTOINCREMENT,"
                        "target TEXT, "
@@ -707,7 +696,7 @@ static bool initSqliteDb(QSqlDatabase& db)
                        "target_accel INTEGER "
                        ")"));
 
-    queryMain.exec(U(
+    queryMain.exec(QStringLiteral(
                        "CREATE TABLE IF NOT EXISTS main ("
                        "id INTEGER PRIMARY KEY ON CONFLICT REPLACE, "// AUTOINCREMENT,"
                        "source INTEGER, "
@@ -728,19 +717,19 @@ static bool initSqliteDb(QSqlDatabase& db)
                        //"hits NUMERIC DEFAULT 0"
                        ")"));
 
-    queryMain.exec(U("CREATE INDEX IF NOT EXISTS source_index ON source_strings ("
+    queryMain.exec(QStringLiteral("CREATE INDEX IF NOT EXISTS source_index ON source_strings ("
                      "source"
                      ")"));
 
-    queryMain.exec(U("CREATE INDEX IF NOT EXISTS target_index ON target_strings ("
+    queryMain.exec(QStringLiteral("CREATE INDEX IF NOT EXISTS target_index ON target_strings ("
                      "target"
                      ")"));
 
-    queryMain.exec(U("CREATE INDEX IF NOT EXISTS main_index ON main ("
+    queryMain.exec(QStringLiteral("CREATE INDEX IF NOT EXISTS main_index ON main ("
                      "source, target, file"
                      ")"));
 
-    queryMain.exec(U(
+    queryMain.exec(QStringLiteral(
                        "CREATE TABLE IF NOT EXISTS files ("
                        "id INTEGER PRIMARY KEY ON CONFLICT REPLACE, "
                        "path TEXT UNIQUE ON CONFLICT REPLACE, "
@@ -761,14 +750,14 @@ static bool initSqliteDb(QSqlDatabase& db)
 
     //we create indexes manually, in a customized way
 //OR: SELECT (tm_links.id) FROM tm_links,words WHERE tm_links.wordid==words.wordid AND (words.word) IN ("africa","abidjan");
-    queryMain.exec(U(
+    queryMain.exec(QStringLiteral(
                        "CREATE TABLE IF NOT EXISTS words ("
                        "word TEXT UNIQUE ON CONFLICT REPLACE, "
                        "ids_short BLOB, " // actually, it's text,
                        "ids_long BLOB "   // but it will never contain non-latin chars
                        ")"));
 
-    queryMain.exec(U(
+    queryMain.exec(QStringLiteral(
                        "CREATE TABLE IF NOT EXISTS tm_config ("
                        "key INTEGER PRIMARY KEY ON CONFLICT REPLACE, "// AUTOINCREMENT,"
                        "value TEXT "
@@ -791,7 +780,7 @@ static void initPgDb(QSqlDatabase& db)
 {
     QSqlQuery queryMain(db);
     queryMain.exec(QStringLiteral("CREATE SEQUENCE source_id_serial"));
-    queryMain.exec(U(
+    queryMain.exec(QStringLiteral(
                        "CREATE TABLE source_strings ("
                        "id INTEGER PRIMARY KEY DEFAULT nextval('source_id_serial'), "
                        "source TEXT, "
@@ -800,7 +789,7 @@ static void initPgDb(QSqlDatabase& db)
                        ")"));
 
     queryMain.exec(QStringLiteral("CREATE SEQUENCE target_id_serial"));
-    queryMain.exec(U(
+    queryMain.exec(QStringLiteral(
                        "CREATE TABLE target_strings ("
                        "id INTEGER PRIMARY KEY DEFAULT nextval('target_id_serial'), "
                        "target TEXT, "
@@ -809,7 +798,7 @@ static void initPgDb(QSqlDatabase& db)
                        ")"));
 
     queryMain.exec(QStringLiteral("CREATE SEQUENCE main_id_serial"));
-    queryMain.exec(U(
+    queryMain.exec(QStringLiteral(
                        "CREATE TABLE main ("
                        "id INTEGER PRIMARY KEY DEFAULT nextval('main_id_serial'), "
                        "source INTEGER, "
@@ -823,20 +812,20 @@ static void initPgDb(QSqlDatabase& db)
                        "prior INTEGER"// helps restoring full context!
                        ")"));
 
-    queryMain.exec(U("CREATE INDEX source_index ON source_strings ("
+    queryMain.exec(QStringLiteral("CREATE INDEX source_index ON source_strings ("
                      "source"
                      ")"));
 
-    queryMain.exec(U("CREATE INDEX target_index ON target_strings ("
+    queryMain.exec(QStringLiteral("CREATE INDEX target_index ON target_strings ("
                      "target"
                      ")"));
 
-    queryMain.exec(U("CREATE INDEX main_index ON main ("
+    queryMain.exec(QStringLiteral("CREATE INDEX main_index ON main ("
                      "source, target, file"
                      ")"));
 
     queryMain.exec(QStringLiteral("CREATE SEQUENCE file_id_serial"));
-    queryMain.exec(U("CREATE TABLE files ("
+    queryMain.exec(QStringLiteral("CREATE TABLE files ("
                      "id INTEGER PRIMARY KEY DEFAULT nextval('file_id_serial'), "
                      "path TEXT UNIQUE, "
                      "date DATE DEFAULT CURRENT_DATE " //last edit date when last scanned
@@ -844,13 +833,13 @@ static void initPgDb(QSqlDatabase& db)
 
     //we create indexes manually, in a customized way
 //OR: SELECT (tm_links.id) FROM tm_links,words WHERE tm_links.wordid==words.wordid AND (words.word) IN ("africa","abidjan");
-    queryMain.exec(U("CREATE TABLE words ("
+    queryMain.exec(QStringLiteral("CREATE TABLE words ("
                      "word TEXT UNIQUE, "
                      "ids_short BYTEA, " // actually, it's text,
                      "ids_long BYTEA "   //` but it will never contain non-latin chars
                      ")"));
 
-    queryMain.exec(U("CREATE TABLE tm_config ("
+    queryMain.exec(QStringLiteral("CREATE TABLE tm_config ("
                      "key INTEGER PRIMARY KEY, "// AUTOINCREMENT,"
                      "value TEXT "
                      ")"));
@@ -859,7 +848,7 @@ static void initPgDb(QSqlDatabase& db)
     //markup
 //(see a little below)
 
-    queryMain.exec(U(
+    queryMain.exec(QStringLiteral(
                        "CREATE OR REPLACE FUNCTION set_user_id() RETURNS trigger AS $$"
                        "BEGIN"
                        "  NEW.change_author = (SELECT usesysid FROM pg_user WHERE usename = CURRENT_USER);"
@@ -967,8 +956,6 @@ OpenDBJob::OpenDBJob(const QString& name, DbType type, bool reconnect, const Con
     : QObject(), QRunnable()
     , m_dbName(name)
     , m_type(type)
-    , m_setParams(false)
-    , m_connectionSuccessful(false)
     , m_reconnect(reconnect)
     , m_connParams(connParams)
 {
@@ -988,7 +975,7 @@ void OpenDBJob::run()
             QString dbFolder = QStandardPaths::writableLocation(QStandardPaths::DataLocation);
             QFileInfo fileInfo(dbFolder);
             if (!fileInfo.exists(dbFolder)) fileInfo.absoluteDir().mkpath(fileInfo.fileName());
-            db.setDatabaseName(dbFolder + QLatin1Char('/') + m_dbName + TM_DATABASE_EXTENSION);
+            db.setDatabaseName(dbFolder + QLatin1Char('/') + m_dbName + QLatin1String(TM_DATABASE_EXTENSION));
             m_connectionSuccessful = db.open();
             if (Q_UNLIKELY(!m_connectionSuccessful)) {
                 qCWarning(LOKALIZE_LOG) << "failed to open db" << db.databaseName() << db.lastError().text();
@@ -1019,7 +1006,7 @@ void OpenDBJob::run()
             }
 
             if (!m_connParams.isFilled()) {
-                QFile rdb(QStandardPaths::writableLocation(QStandardPaths::DataLocation) + QLatin1Char('/') + m_dbName + REMOTETM_DATABASE_EXTENSION);
+                QFile rdb(QStandardPaths::writableLocation(QStandardPaths::DataLocation) + QLatin1Char('/') + m_dbName + QLatin1String(REMOTETM_DATABASE_EXTENSION));
                 if (!rdb.open(QIODevice::ReadOnly | QIODevice::Text)) {
                     Q_EMIT done(this);
                     return;
@@ -1083,7 +1070,7 @@ CloseDBJob::~CloseDBJob()
 void CloseDBJob::run()
 {
     const QString connectionName = getConnectionName(m_dbName);
-    if (connectionName.length())
+    if (!connectionName.isEmpty())
         QSqlDatabase::removeDatabase(connectionName);
     qCDebug(LOKALIZE_LOG) << "closedb " << connectionName;
     Q_EMIT done(this);
@@ -1104,7 +1091,7 @@ static QString makeAcceledString(QString source, const QString& accel, const QVa
 SelectJob* TM::initSelectJob(Catalog* catalog, DocPosition pos, QString db, int opt)
 {
     SelectJob* job = new SelectJob(catalog->sourceWithTags(pos),
-                                   catalog->context(pos.entry).first(),
+                                   catalog->context(DocPosition(pos.entry)).first(),
                                    catalog->url(),
                                    pos,
                                    db.isEmpty() ? Project::instance()->projectID() : db);
@@ -1124,7 +1111,6 @@ SelectJob::SelectJob(const CatalogString& source,
     , m_source(source)
     , m_ctxt(ctxt)
     , m_file(file)
-    , m_dequeued(false)
     , m_pos(pos)
     , m_dbName(dbName)
 {
@@ -1132,17 +1118,12 @@ SelectJob::SelectJob(const CatalogString& source,
     //qCDebug(LOKALIZE_LOG)<<"selectjob"<<dbName<<m_source.string;
 }
 
-SelectJob::~SelectJob()
-{
-    //qCDebug(LOKALIZE_LOG)<<m_source.string;
-}
-
 inline QMap<uint, qlonglong> invertMap(const QMap<qlonglong, uint>& source)
 {
     //uses the fact that map has its keys always sorted
-    QMap<uint, qlonglong> sortingMap;
+    QMultiMap<uint, qlonglong> sortingMap;
     for (QMap<qlonglong, uint>::const_iterator i = source.constBegin(); i != source.constEnd(); ++i) {
-        sortingMap.insertMulti(i.value(), i.key());
+        sortingMap.insert(i.value(), i.key());
     }
     return sortingMap;
 }
@@ -1159,8 +1140,8 @@ bool SelectJob::doSelect(QSqlDatabase& db,
 
     QSqlQuery queryWords(db);
     //TODO ??? not sure. make another loop before to create QList< QList<qlonglong> > then reorder it by size
-    static const QString queryC[] = {U("SELECT ids_long FROM words WHERE word='%1'"),
-                                     U("SELECT ids_short FROM words WHERE word='%1'")
+    static const QString queryC[] = {QStringLiteral("SELECT ids_long FROM words WHERE word='%1'"),
+                                     QStringLiteral("SELECT ids_short FROM words WHERE word='%1'")
                                     };
     QString queryString = queryC[isShort];
 
@@ -1200,7 +1181,7 @@ bool SelectJob::doSelect(QSqlDatabase& db,
     TMConfig c = getConfig(db);
     QString tmp = c.markup;
     if (!c.markup.isEmpty())
-        tmp += '|';
+        tmp += QLatin1Char('|');
     QRegExp rxSplit(QLatin1Char('(') + tmp + QStringLiteral("\\W+|\\d+)+"));
 
     QString sourceClean(m_source.string);
@@ -1228,7 +1209,7 @@ bool SelectJob::doSelect(QSqlDatabase& db,
             qlonglong level = clit.key();
             QString joined;
             while (level == clit.key()) {
-                joined += QString::number(clit.value()) + ',';
+                joined += QString::number(clit.value()) + QLatin1Char(',');
                 if (clit == concordanceLevelToIds.constBegin() || --limit < 0)
                     break;
                 --clit;
@@ -1236,9 +1217,9 @@ bool SelectJob::doSelect(QSqlDatabase& db,
             joined.chop(1);
 
             //get records containing current word
-            QSqlQuery queryFetch(U(
+            QSqlQuery queryFetch(QStringLiteral(
                                      "SELECT id, source, source_accel, source_markup FROM source_strings WHERE "
-                                     "source_strings.id IN (") + joined + ')', db);
+                                     "source_strings.id IN (") + joined + QLatin1Char(')'), db);
             TMEntry e;
             while (queryFetch.next()) {
                 e.id = queryFetch.value(0).toLongLong();
@@ -1343,19 +1324,19 @@ bool SelectJob::doSelect(QSqlDatabase& db,
                     authors_table_str = QStringLiteral(" JOIN pg_user ON (pg_user.usesysid=main.change_author) ");
                 }
 
-                QSqlQuery queryRest(U(
+                QSqlQuery queryRest(QStringLiteral(
                                         "SELECT main.id, main.date, main.ctxt, main.bits, "
                                         "target_strings.target, target_strings.target_accel, target_strings.target_markup, "
-                                        "files.path, main.change_date ") + change_author_str + U(
+                                        "files.path, main.change_date ") + change_author_str + QStringLiteral(
                                         "FROM main JOIN target_strings ON (target_strings.id=main.target) JOIN files ON (files.id=main.file) ")
-                                    + authors_table_str + U("WHERE "
-                                            "main.source=") + QString::number(e.id) + U(" AND "
+                                    + authors_table_str + QStringLiteral("WHERE "
+                                            "main.source=") + QString::number(e.id) + QStringLiteral(" AND "
                                                     "(main.bits&4)!=4 AND "
                                                     "target_strings.target NOTNULL")
                                     , db); //ORDER BY tm_main.id ?
                 queryRest.exec();
                 //qCDebug(LOKALIZE_LOG)<<"main select error"<<queryRest.lastError().text();
-                QMap<TMEntry, bool> sortedEntryList; //to eliminate same targets from different files
+                QMultiMap<TMEntry, bool> sortedEntryList; //to eliminate same targets from different files
                 while (queryRest.next()) {
                     e.id = queryRest.value(0).toLongLong();
                     e.date = queryRest.value(1).toDate();
@@ -1363,7 +1344,7 @@ bool SelectJob::doSelect(QSqlDatabase& db,
                     e.target = CatalogString(makeAcceledString(queryRest.value(4).toString(), c.accel, queryRest.value(5)),
                                              queryRest.value(6).toByteArray());
 
-                    QStringList matchData = queryRest.value(2).toString().split(TM_DELIMITER, Qt::KeepEmptyParts); //context|plural
+                    QStringList matchData = queryRest.value(2).toString().split(QLatin1Char(TM_DELIMITER), Qt::KeepEmptyParts); //context|plural
                     e.file = queryRest.value(7).toString();
                     if (e.target.isEmpty())
                         continue;
@@ -1400,7 +1381,7 @@ bool SelectJob::doSelect(QSqlDatabase& db,
                         e.score += 33;
 //END exact match score++
                     //qCWarning(LOKALIZE_LOG)<<"appending"<<e.target;
-                    sortedEntryList.insertMulti(e, false);
+                    sortedEntryList.insert(e, false);
                 }
                 queryRest.clear();
                 //eliminate same targets from different files
@@ -1559,7 +1540,7 @@ void ScanJob::run()
                     */
                     ok = ok && doInsertEntry(catalog.sourceWithTags(ppos),
                                              catalog.targetWithTags(ppos),
-                                             catalog.context(ppos).first() + TM_DELIMITER + QString::number(ppos.form),
+                                             catalog.context(ppos).first() + QLatin1Char(TM_DELIMITER) + QString::number(ppos.form),
                                              catalog.isApproved(ppos),
                                              fileId, db, rxClean1, c.accel, priorId, priorId);
                 }
@@ -1706,7 +1687,7 @@ void UpdateJob::run()
     qlonglong fileId = getFileId(m_filePath, db);
 
     if (m_form != -1)
-        m_ctxt += TM_DELIMITER + QString::number(m_form);
+        m_ctxt += QLatin1Char(TM_DELIMITER) + QString::number(m_form);
 
     QSqlQuery queryBegin(QStringLiteral("BEGIN"), db);
     qlonglong priorId = -1;
@@ -1721,12 +1702,12 @@ void UpdateJob::run()
 //BEGIN TMX
 
 #include <QXmlDefaultHandler>
-#include <QXmlSimpleReader>
+#include <QXmlStreamReader>
 
 /**
     @author Nick Shaforostoff <shafff@ukr.net>
 */
-class TmxParser : public QXmlDefaultHandler
+class TmxParser
 {
     enum State { //localstate for getting chars into right place
         null = 0,
@@ -1747,18 +1728,17 @@ public:
     TmxParser(const QString& dbName);
     ~TmxParser();
 
-private:
-    bool startDocument() override;
-    bool startElement(const QString&, const QString&, const QString&, const QXmlAttributes&) override;
-    bool endElement(const QString&, const QString&, const QString&) override;
-    bool characters(const QString&) override;
+    bool startDocument();
+    bool startElement(const QString&, const QXmlStreamAttributes&);
+    bool endElement(const QString&);
+    bool characters(const QString&);
 
 private:
     QSqlDatabase db;
     QRegExp rxClean1;
     QString accel;
 
-    int m_hits;
+    int m_hits{0};
     CatalogString m_segment[3]; //Lang enum
     QList<InlineTag> m_inlineTags;
     QString m_context;
@@ -1769,7 +1749,7 @@ private:
     State m_state: 8;
     Lang m_lang: 8;
 
-    ushort m_added;
+    ushort m_added{0};
 
 
     QMap<QString, qlonglong> m_fileIds;
@@ -1778,14 +1758,11 @@ private:
 
 
 TmxParser::TmxParser(const QString& dbName)
-    : m_hits(0)
+    : db(QSqlDatabase::database(dbName))
     , m_state(null)
     , m_lang(Null)
-    , m_added(0)
     , m_dbLangCode(Project::instance()->langCode().toLower())
 {
-    db = QSqlDatabase::database(dbName);
-
     TMConfig c = getConfig(db);
     rxClean1.setPattern(c.markup); rxClean1.setMinimal(true);
     accel = c.accel;
@@ -1810,9 +1787,8 @@ TmxParser::~TmxParser()
 }
 
 
-bool TmxParser::startElement(const QString&, const QString&,
-                             const QString& qName,
-                             const QXmlAttributes& attr)
+bool TmxParser::startElement(const QString& qName,
+                             const QXmlStreamAttributes& attr)
 {
     if (qName == QLatin1String("tu")) {
         bool ok;
@@ -1828,17 +1804,17 @@ bool TmxParser::startElement(const QString&, const QString&,
         m_approvedString.clear();
 
     } else if (qName == QLatin1String("tuv")) {
-        QString attrLang = attr.value(QStringLiteral("xml:lang")).toLower();
+        QString attrLang = attr.value(QStringLiteral("xml:lang")).toString().toLower();
         if (attrLang == QLatin1String("en")) //TODO startsWith?
             m_lang = Source;
         else if (attrLang == m_dbLangCode)
             m_lang = Target;
         else {
-            qCWarning(LOKALIZE_LOG) << "skipping lang" << attr.value("xml:lang");
+            qCWarning(LOKALIZE_LOG) << "skipping lang" << attr.value(QStringLiteral("xml:lang"));
             m_lang = Null;
         }
     } else if (qName == QLatin1String("prop")) {
-        QString attrType = attr.value(QStringLiteral("type")).toLower();
+        QString attrType = attr.value(QStringLiteral("type")).toString().toLower();
         if (attrType == QLatin1String("x-context"))
             m_state = propContext;
         else if (attrType == QLatin1String("x-file"))
@@ -1856,13 +1832,13 @@ bool TmxParser::startElement(const QString&, const QString&,
         if (t != InlineTag::_unknown) {
             m_segment[m_lang].string += QChar(TAGRANGE_IMAGE_SYMBOL);
             int pos = m_segment[m_lang].string.size();
-            m_inlineTags.append(InlineTag(pos, pos, t, attr.value(QStringLiteral("id"))));
+            m_inlineTags.append(InlineTag(pos, pos, t, attr.value(QStringLiteral("id")).toString()));
         }
     }
     return true;
 }
 
-bool TmxParser::endElement(const QString&, const QString&, const QString& qName)
+bool TmxParser::endElement(const QString& qName)
 {
     if (qName == QLatin1String("tu")) {
         if (m_filePath.isEmpty())
@@ -1872,7 +1848,7 @@ bool TmxParser::endElement(const QString&, const QString&, const QString& qName)
         qlonglong fileId = m_fileIds.value(m_filePath);
 
         if (!m_pluralForm.isEmpty())
-            m_context += TM_DELIMITER + m_pluralForm;
+            m_context += QLatin1Char(TM_DELIMITER) + m_pluralForm;
 
         qlonglong priorId = -1;
         bool ok = doInsertEntry(m_segment[Source],
@@ -1924,7 +1900,6 @@ bool TmxParser::characters(const QString& ch)
 ImportTmxJob::ImportTmxJob(const QString& filename, const QString& dbName)
     : QRunnable()
     , m_filename(filename)
-    , m_time(0)
     , m_dbName(dbName)
 {
 }
@@ -1943,11 +1918,29 @@ void ImportTmxJob::run()
         return;
 
     TmxParser parser(m_dbName);
-    QXmlSimpleReader reader;
-    reader.setContentHandler(&parser);
+    QXmlStreamReader reader(&file);
 
-    QXmlInputSource xmlInputSource(&file);
-    if (!reader.parse(xmlInputSource))
+    while (!reader.atEnd()) {
+        reader.readNext();
+        if(reader.isStartElement()) {
+            QString name = reader.name().toString();
+            QXmlStreamAttributes attr = reader.attributes();
+            parser.startElement(name, attr);
+        }
+        else if(reader.isEndElement()) {
+            QString name = reader.name().toString();
+            parser.endElement(name);
+        }
+        else if(reader.isCharacters()) {
+            QString text = reader.text().toString();
+            parser.characters(text);
+        }
+        else if(reader.isStartDocument()) {
+            parser.startDocument();
+        }
+    }
+
+    if (reader.hasError())
         qCWarning(LOKALIZE_LOG) << "failed to load" << m_filename;
 
     //qCWarning(LOKALIZE_LOG) <<"Done scanning "<<m_url.prettyUrl();
@@ -1962,7 +1955,6 @@ void ImportTmxJob::run()
 ExportTmxJob::ExportTmxJob(const QString& filename, const QString& dbName)
     : QRunnable()
     , m_filename(filename)
-    , m_time(0)
     , m_dbName(dbName)
 {
 }
@@ -2006,7 +1998,7 @@ void ExportTmxJob::run()
     QSqlDatabase db = QSqlDatabase::database(connectionName);
     QSqlQuery query1(db);
 
-    if (Q_UNLIKELY(!query1.exec(U(
+    if (Q_UNLIKELY(!query1.exec(QStringLiteral(
                                     "SELECT main.id, main.ctxt, main.date, main.bits, "
                                     "source_strings.source, source_strings.source_accel, "
                                     "target_strings.target, target_strings.target_accel, "
@@ -2042,19 +2034,19 @@ void ExportTmxJob::run()
         xmlOut.writeAttribute(QStringLiteral("changedate"), QDate::fromString(query1.value(9).toString(), Qt::ISODate).toString(DATE_FORMAT));
         QString ctxt = query1.value(1).toString();
         if (!ctxt.isEmpty()) {
-            int pos = ctxt.indexOf(TM_DELIMITER);
+            int pos = ctxt.indexOf(QLatin1Char(TM_DELIMITER));
             if (pos != -1) {
                 QString plural = ctxt;
                 plural.remove(0, pos + 1);
                 ctxt.remove(pos, plural.size());
                 xmlOut.writeStartElement(PROP);
-                xmlOut.writeAttribute(TYPE, "x-pluralform");
+                xmlOut.writeAttribute(TYPE, QStringLiteral("x-pluralform"));
                 xmlOut.writeCharacters(plural);
                 xmlOut.writeEndElement();
             }
             if (!ctxt.isEmpty()) {
                 xmlOut.writeStartElement(PROP);
-                xmlOut.writeAttribute(TYPE, "x-context");
+                xmlOut.writeAttribute(TYPE, QStringLiteral("x-context"));
                 xmlOut.writeCharacters(ctxt);
                 xmlOut.writeEndElement();
             }
@@ -2062,7 +2054,7 @@ void ExportTmxJob::run()
         QString filePath = query1.value(8).toString();
         if (!filePath.isEmpty()) {
             xmlOut.writeStartElement(PROP);
-            xmlOut.writeAttribute(TYPE, "x-file");
+            xmlOut.writeAttribute(TYPE, QStringLiteral("x-file"));
             xmlOut.writeCharacters(filePath);
             xmlOut.writeEndElement();
         }
@@ -2070,8 +2062,8 @@ void ExportTmxJob::run()
         if (bits & TM_NOTAPPROVED)
             if (!filePath.isEmpty()) {
                 xmlOut.writeStartElement(PROP);
-                xmlOut.writeAttribute(TYPE, "x-approved");
-                xmlOut.writeCharacters("no");
+                xmlOut.writeAttribute(TYPE, QStringLiteral("x-approved"));
+                xmlOut.writeCharacters(QStringLiteral("no"));
                 xmlOut.writeEndElement();
             }
         xmlOut.writeStartElement(QStringLiteral("seg"));
@@ -2099,7 +2091,6 @@ void ExportTmxJob::run()
 
 ExecQueryJob::ExecQueryJob(const QString& queryString, const QString& dbName, QMutex *dbOperation)
     : QObject(), QRunnable()
-    , query(nullptr)
     , m_dbName(dbName)
     , m_query(queryString)
     , m_dbOperationMutex(dbOperation)
@@ -2132,4 +2123,4 @@ void ExecQueryJob::run()
     Q_EMIT done(this);
 }
 
-
+#include "moc_jobs.cpp"
