@@ -74,8 +74,7 @@ void TMManagerWin::addDir()
 
 
 DBPropertiesDialog::DBPropertiesDialog(QWidget* parent, const QString& dbName)
-    : QDialog(parent), Ui_DBParams()
-    , m_connectionOptionsValid(false)
+    : QDialog(parent)
 {
     setAttribute(Qt::WA_DeleteOnClose, true);
     setWindowTitle(dbName.isEmpty() ? i18nc("@title:window", "New Translation Memory") : i18nc("@title:window", "Translation Memory Properties"));
@@ -98,18 +97,18 @@ DBPropertiesDialog::DBPropertiesDialog(QWidget* parent, const QString& dbName)
     }
 
     connectionBox->hide();
-    connect(dbType, QOverload<int>::of(&QComboBox::activated), this, &DBPropertiesDialog::setConnectionBoxVisible);
+    connect(dbType, qOverload<int>(&QComboBox::activated), this, &DBPropertiesDialog::setConnectionBoxVisible);
     m_checkDelayer.setInterval(2000);
     m_checkDelayer.setSingleShot(true);
     connect(&m_checkDelayer, &QTimer::timeout, this, &DBPropertiesDialog::checkConnectionOptions);
-    connect(this->dbName, &QLineEdit::textChanged, &m_checkDelayer, QOverload<>::of(&QTimer::start));
-    connect(dbHost->lineEdit(), &QLineEdit::textChanged, &m_checkDelayer, QOverload<>::of(&QTimer::start));
-    connect(dbUser, &QLineEdit::textChanged, &m_checkDelayer, QOverload<>::of(&QTimer::start));
-    connect(dbPasswd, &QLineEdit::textChanged, &m_checkDelayer, QOverload<>::of(&QTimer::start));
+    connect(this->dbName, &QLineEdit::textChanged, &m_checkDelayer, qOverload<>(&QTimer::start));
+    connect(dbHost->lineEdit(), &QLineEdit::textChanged, &m_checkDelayer, qOverload<>(&QTimer::start));
+    connect(dbUser, &QLineEdit::textChanged, &m_checkDelayer, qOverload<>(&QTimer::start));
+    connect(dbPasswd, &QLineEdit::textChanged, &m_checkDelayer, qOverload<>(&QTimer::start));
 
     QStringList drivers = QSqlDatabase::drivers();
-    if (drivers.contains("QPSQL"))
-        dbType->addItem("PostgreSQL");
+    if (drivers.contains(QStringLiteral("QPSQL")))
+        dbType->addItem(QStringLiteral("PostgreSQL"));
 }
 
 void DBPropertiesDialog::setConnectionBoxVisible(int type)
@@ -130,7 +129,7 @@ void DBPropertiesDialog::checkConnectionOptions()
         return;
 
     OpenDBJob::ConnectionParams connParams;
-    connParams.driver = "QPSQL";
+    connParams.driver = QLatin1String("QPSQL");
     connParams.host = dbHost->currentText();
     connParams.db = dbName->text();
     connParams.user = dbUser->text();
@@ -171,7 +170,7 @@ void DBPropertiesDialog::accept()
         return;
 
     if (connectionBox->isVisible()) {
-        QFile rdb(QStandardPaths::writableLocation(QStandardPaths::DataLocation) + QLatin1Char('/') + name->text() + REMOTETM_DATABASE_EXTENSION);
+        QFile rdb(QStandardPaths::writableLocation(QStandardPaths::DataLocation) + QLatin1Char('/') + name->text() + QLatin1String(REMOTETM_DATABASE_EXTENSION));
         if (!rdb.open(QIODevice::WriteOnly | QIODevice::Text | QIODevice::Truncate))
             return;
 
@@ -254,5 +253,4 @@ void TMManagerWin::slotItemActivated(const QModelIndex&)
         win->show();*/
 }
 
-
-
+#include "moc_tmmanager.cpp"
