@@ -50,7 +50,7 @@ inline static QImage generateImage(const QString& str, const QFont& font)
 
     QStyleOptionButton opt;
     opt.fontMetrics = QFontMetrics(font);
-    opt.text = ' ' + str + ' ';
+    opt.text = QLatin1Char(' ') + str + QLatin1Char(' ');
     opt.rect = opt.fontMetrics.boundingRect(opt.text).adjusted(0, 0, 5, 5);
     opt.rect.moveTo(0, 0);
 
@@ -66,7 +66,7 @@ inline static QImage generateImage(const QString& str, const QFont& font)
 class MyCompletionBox: public KCompletionBox
 {
 public:
-    MyCompletionBox(QWidget* p): KCompletionBox(p) {}
+    explicit MyCompletionBox(QWidget* p): KCompletionBox(p) {}
     ~MyCompletionBox() override = default;
     QSize sizeHint() const override;
 
@@ -100,15 +100,10 @@ TranslationUnitTextEdit::~TranslationUnitTextEdit()
 
 TranslationUnitTextEdit::TranslationUnitTextEdit(Catalog* catalog, DocPosition::Part part, QWidget* parent)
     : KTextEdit(parent)
-    , m_currentUnicodeNumber(0)
-    , m_langUsesSpaces(true)
     , m_catalog(catalog)
     , m_part(part)
     , m_highlighter(new SyntaxHighlighter(this))
     , m_enabled(Settings::autoSpellcheck())
-    , m_completionBox(nullptr)
-    , m_cursorSelectionStart(0)
-    , m_cursorSelectionEnd(0)
     , m_languageToolTimer(new QTimer(this))
 {
     setReadOnly(part == DocPosition::Source);
@@ -123,7 +118,7 @@ TranslationUnitTextEdit::TranslationUnitTextEdit(Catalog* catalog, DocPosition::
         connect(this, &KTextEdit::cursorPositionChanged, this, &TranslationUnitTextEdit::emitCursorPositionChanged);
         connect(m_languageToolTimer, &QTimer::timeout, this, &TranslationUnitTextEdit::launchLanguageTool);
     }
-    connect(catalog, QOverload<>::of(&Catalog::signalFileLoaded), this, &TranslationUnitTextEdit::fileLoaded);
+    connect(catalog, qOverload<>(&Catalog::signalFileLoaded), this, &TranslationUnitTextEdit::fileLoaded);
     //connect (Project::instance(), &Project::configChanged, this, &TranslationUnitTextEdit::projectConfigChanged);
     m_languageToolTimer->setSingleShot(true);
 }
@@ -415,8 +410,8 @@ void insertContent(QTextCursor& cursor, const CatalogString& catStr, const Catal
 
 
     void TranslationUnitTextEdit::contentsChanged(int offset, int charsRemoved, int charsAdded) {
-        Q_ASSERT(m_catalog->targetLangCode().length());
-        Q_ASSERT(Project::instance()->targetLangCode().length());
+        Q_ASSERT(!m_catalog->targetLangCode().isEmpty());
+        Q_ASSERT(!Project::instance()->targetLangCode().isEmpty());
 
         //qCWarning(LOKALIZE_LOG)<<"contentsChanged. offset"<<offset<<"charsRemoved"<<charsRemoved<<"charsAdded"<<charsAdded<<"_oldMsgstr"<<_oldMsgstr;
 
@@ -436,7 +431,7 @@ void insertContent(QTextCursor& cursor, const CatalogString& catStr, const Catal
         }
 
         //ktextedit spellcheck handling:
-        if (charsRemoved == 0 && editText.isEmpty() && _oldMsgstr.length())
+        if (charsRemoved == 0 && editText.isEmpty() && !_oldMsgstr.isEmpty())
             charsRemoved = _oldMsgstr.length();
         if (charsAdded && editText.isEmpty())
             charsAdded = 0;
@@ -538,7 +533,7 @@ void insertContent(QTextCursor& cursor, const CatalogString& catStr, const Catal
             //qCWarning(LOKALIZE_LOG)<<"calling showPos";
             showPos(m_currentPos, CatalogString(),/*keepCursor*/true/*false*/);
         }
-        Q_EMIT contentsModified(m_currentPos.entry);
+        Q_EMIT contentsModified(DocPosition(m_currentPos.entry));
         return true;
     }
 
@@ -704,7 +699,7 @@ void insertContent(QTextCursor& cursor, const CatalogString& catStr, const Catal
         uint counter = 0;
         int pos = col;
 
-        while (pos >= 0 && str.at(pos) == '\\') {
+        while (pos >= 0 && str.at(pos) == QLatin1Char('\\')) {
             counter++;
             pos--;
         }
@@ -810,7 +805,7 @@ void insertContent(QTextCursor& cursor, const CatalogString& catStr, const Catal
                     && !str.isEmpty()
                     && str.at(pos - 1) == QLatin1Char('\\')
                     && !isMasked(str, pos - 1)) {
-                    ins = 'n';
+                    ins = QLatin1Char('n');
                 } else {
                     ins = QStringLiteral("\\n");
                 }
@@ -830,7 +825,7 @@ void insertContent(QTextCursor& cursor, const CatalogString& catStr, const Catal
                 }
             }
             if (!str.isEmpty()) {
-                ins += '\n';
+                ins += QLatin1Char('\n');
                 insertPlainTextWithCursorCheck(ins);
             } else
                 KTextEdit::keyPressEvent(keyEvent);
@@ -848,7 +843,7 @@ void insertContent(QTextCursor& cursor, const CatalogString& catStr, const Catal
                 //workaround for Qt/X11 bug: if Del on NumPad is pressed, then pos is beyond end
                 if (pos == str.size()) --pos;
                 if (!str.isEmpty()
-                    && str.at(pos) == '\\'
+                    && str.at(pos) == QLatin1Char('\\')
                     && !isMasked(str, pos)
                     && pos < str.length() - 1
                     && spclChars.contains(str.at(pos + 1))) {
@@ -899,7 +894,7 @@ void insertContent(QTextCursor& cursor, const CatalogString& catStr, const Catal
         QTextCursor cursor = textCursor();
         cursor.select(QTextCursor::Document);
         QString text = cursor.selectedText();
-        text.replace(QChar(8233), '\n');
+        text.replace(QChar(8233), QLatin1Char('\n'));
         /*
             int ii=text.size();
             while(--ii>=0)
@@ -1126,7 +1121,7 @@ void insertContent(QTextCursor& cursor, const CatalogString& catStr, const Catal
             QLocale l(langCode);
             if (l.language() != QLocale::C) tip = l.nativeLanguageName() + QLatin1String(" (");
             tip += langCode;
-            if (l.language() != QLocale::C) tip += ')';
+            if (l.language() != QLocale::C) tip += QLatin1Char(')');
             if (nospell)
                 tip += QLatin1String(" - ") + i18n("no spellcheck available");
             QToolTip::showText(helpEvent->globalPos(), tip);
@@ -1146,7 +1141,7 @@ void insertContent(QTextCursor& cursor, const CatalogString& catStr, const Catal
     }
 
     void TranslationUnitTextEdit::launchLanguageTool()     {
-        if (toPlainText().length() == 0)
+        if (toPlainText().isEmpty())
             return;
 
         LanguageToolResultJob *job = new LanguageToolResultJob(this);
@@ -1200,8 +1195,8 @@ void insertContent(QTextCursor& cursor, const CatalogString& catStr, const Catal
             tag.setMinimal(true);
             QString en = m_catalog->sourceWithTags(m_currentPos).string;
             QString target(toPlainText());
-            en.remove('\n');
-            target.remove('\n');
+            en.remove(QLatin1Char('\n'));
+            target.remove(QLatin1Char('\n'));
             int pos = 0;
             //tag.indexIn(en);
             int posInMsgStr = 0;
@@ -1235,7 +1230,7 @@ void insertContent(QTextCursor& cursor, const CatalogString& catStr, const Catal
         CatalogString sourceWithTags = m_catalog->sourceWithTags(m_currentPos);
         QString text = sourceWithTags.string;
         QString out;
-        QString ctxt = m_catalog->context(m_currentPos.entry).first();
+        QString ctxt = m_catalog->context(DocPosition(m_currentPos.entry)).first();
         QRegExp delimiter(QStringLiteral("\\s*,\\s*"));
 
         //TODO ask for the fillment if the first time.
@@ -1254,15 +1249,15 @@ void insertContent(QTextCursor& cursor, const CatalogString& catStr, const Catal
             }
         } else if (/*_catalog->isGeneratedFromDocbook() &&*/ text.startsWith(QLatin1String("ROLES_OF_TRANSLATORS"))) {
             if (!document()->isEmpty())
-                out = '\n';
+                out = QLatin1Char('\n');
             out += QLatin1String("<othercredit role=\\\"translator\\\">\n"
                                  "<firstname></firstname><surname></surname>\n"
                                  "<affiliation><address><email>") + Settings::authorEmail() + QLatin1String("</email></address>\n"
                                          "</affiliation><contrib></contrib></othercredit>");
         } else if (text.startsWith(QLatin1String("CREDIT_FOR_TRANSLATORS"))) {
             if (!document()->isEmpty())
-                out = '\n';
-            out += QLatin1String("<para>") + Settings::authorLocalizedName() + '\n' +
+                out = QLatin1Char('\n');
+            out += QLatin1String("<para>") + Settings::authorLocalizedName() + QLatin1Char('\n') +
                    QLatin1String("<email>") + Settings::authorEmail() + QLatin1String("</email></para>");
         }
         //END KDE specific part
@@ -1318,7 +1313,7 @@ void insertContent(QTextCursor& cursor, const CatalogString& catStr, const Catal
         if (!m_completionBox) {
 //BEGIN creation
             m_completionBox = new MyCompletionBox(this);
-            connect(m_completionBox, &MyCompletionBox::activated, this, &TranslationUnitTextEdit::completionActivated);
+            connect(m_completionBox, &MyCompletionBox::textActivated, this, &TranslationUnitTextEdit::completionActivated);
             m_completionBox->setSizePolicy(QSizePolicy::Maximum, QSizePolicy::Preferred);
 //END creation
         }
@@ -1331,7 +1326,7 @@ void insertContent(QTextCursor& cursor, const CatalogString& catStr, const Catal
             m_completionBox->resize(m_completionBox->sizeHint());
             QPoint p = cursorRect().bottomRight();
             if (p.x() < 10) //workaround Qt bug
-                p.rx() += textCursor().verticalMovementX() + QFontMetrics(currentFont()).horizontalAdvance('W');
+                p.rx() += textCursor().verticalMovementX() + QFontMetrics(currentFont()).horizontalAdvance(QLatin1Char('W'));
             m_completionBox->move(viewport()->mapToGlobal(p));
         } else
             m_completionBox->hide();
@@ -1347,3 +1342,4 @@ void insertContent(QTextCursor& cursor, const CatalogString& catStr, const Catal
         setTextCursor(cursor);
     }
 
+#include "moc_xlifftextedit.cpp"
